#
# spec file for package golang-github-vpenso-prometheus_slurm_exporter
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{go_nostrip}

Name:           golang-github-vpenso-prometheus_slurm_exporter
Version:        0.20
Release:        1.9
Summary:        Prometheus exporter for Slurm metrics
License:        GPL-3.0-or-later
Group:          System/Management
URL:            https://github.com/vpenso/prometheus-slurm-exporter
Source0:        https://github.com/vpenso/prometheus-slurm-exporter/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        README.SUSE
Patch0:         use_sbin.patch
Patch1:         Adjust-GPU-data-gathering-to-work-with-all-Slurm-versions-since-18.08.patch
BuildRequires:  golang-packaging
%{?systemd_requires}
Requires(pre):  shadow
%{go_provides}
Requires:       /usr/bin/sinfo
Requires:       /usr/bin/squeue

%description
Prometheus collector and exporter for metrics extracted from the Slurm
resource scheduling system.

%prep
%setup -q -n prometheus-slurm-exporter-%{version}
%setup -q -n prometheus-slurm-exporter-%{version} -T -D -a 1
%autopatch -p1

%build
%{goprep} github.com/vpenso/prometheus-slurm-exporter
%{gobuild} -mod=vendor ""

%install
%{goinstall}
# No %%{gosrc}
install -D -m 0644 lib/systemd/prometheus-slurm-exporter.service %{buildroot}%{_unitdir}/prometheus-slurm-exporter.service
sed -i -e '/ExecStart/s@^\(.*\)$@\1 $PROMETHEUS_SLURM_EXPORTER_ARGS@' \
    -e '/\[Service\]/a EnvironmentFile=-%{_sysconfdir}/sysconfig/prometheus-slurm-exporter' \
    %{buildroot}%{_unitdir}/prometheus-slurm-exporter.service
# To handle service file rename
ln -sf prometheus-slurm-exporter.service %{buildroot}%{_unitdir}/prometheus-slurm_exporter.service
install -m 0755 -d %{buildroot}%{_fillupdir}
echo -e '# prometheus-slurm-exporter args\n'\
'# possible values: -gpus-acct, -listen-address string\n'\
'PROMETHEUS_SLURM_EXPORTER_ARGS=""' > \
    %{buildroot}%{_fillupdir}/sysconfig.prometheus-slurm-exporter
mv %{buildroot}%{_bindir}/ %{buildroot}%{_sbindir}/
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcprometheus-slurm-exporter
cp %{S:2} .
%{gofilelist}

%pre
%service_add_pre prometheus-slurm-exporter.service
getent group prometheus >/dev/null || %{_sbindir}/groupadd -r prometheus
getent passwd prometheus >/dev/null || %{_sbindir}/useradd -r -g prometheus -d %{_localstatedir}/lib/prometheus -M -s /sbin/nologin prometheus

%post
%service_add_post prometheus-slurm-exporter.service
%{fillup_only -n prometheus-slurm-exporter}

%preun
%service_del_preun prometheus-slurm-exporter.service

%postun
%service_del_postun prometheus-slurm-exporter.service

%files -f file.lst
%license LICENSE
%doc README.md
%doc %{basename:cp %{S:2}}
%{_fillupdir}/sysconfig.prometheus-slurm-exporter
%{_sbindir}/prometheus-slurm-exporter
%{_unitdir}/prometheus-slurm-exporter.service
%{_unitdir}/prometheus-slurm_exporter.service
%{_sbindir}/rcprometheus-slurm-exporter

%changelog
* Tue Jun 27 2023 Egbert Eich <eich@suse.com>
- Adjust-GPU-data-gathering-to-work-with-all-Slurm-versions-since-18.08.patch
  Fix to make GPU data gathering works with all Slurm versions since 18.08.
- Add a sysconfig settings to make daemon command line args easily.
- Fix service file names to match upstream:
    prometheus-slurm_exporter.service -> prometheus-slurm-exporter.service
    rcprometheus-slurm_exporter -> rcprometheus-slurm-exporter
  To support updates, the old name is still kept as sym-link.
  Add README.SUSE to inform about sysconfig file.
* Thu Jun 16 2022 ecsos <ecsos@opensuse.org>
- Update to 0.20
  * Multiple README fix.
  * Improve build process.
* Thu Jul 22 2021 Egbert Eich <eich@suse.com>
- Update to version 0.19
  * GPUs accounting has to be activated explicitly via cmd line option.
  * Export detailed usage info for every node (CPU, Memory).
  NOTE: With the present version of Slurm (20.11), GPU accounting
  in the prometheus-slurm-exporter will cause the exporter to
  terminate, thus it must not be enabled for the time being.
- Do not ship sources.
* Thu Mar 18 2021 Ana Guerrero Lopez <aguerrero@suse.com>
- New version 0.17
  * Export information about shares via sshare
- New version 0.16
  * Add support to provide information about GPU GREs usage
* Wed Dec  2 2020 Ana Guerrero Lopez <aguerrero@suse.com>
- New version 0.15
  * Metric updates
  * Bugfixes
- Upstream now provides go.mod, update packaging accordingly.
* Wed Dec 18 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- List all source files.
* Wed Dec 11 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Remove grafana-dashboards and do not add the dashboard in the tarball,
  its license needs to be clarified. It's also easier for users
  to install the board from grafana.com
* Fri Dec  6 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Add new package with grafana-dashboards
- Add README.packaging
- Document use_sbin.patch
* Mon Dec  2 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Initial release.
